aboutsummaryrefslogtreecommitdiffstats
path: root/print.c
diff options
context:
space:
mode:
authorBill Meier <wmeier@newsguy.com>2013-02-18 01:18:51 +0000
committerBill Meier <wmeier@newsguy.com>2013-02-18 01:18:51 +0000
commit1c289aa89a866fb25537172a2becc4e78842934b (patch)
tree6e502c1499996954141f361f1acc85c25650782b /print.c
parent0a135e8eb07065560d175ea023a0de361f2d977c (diff)
Don't use index as a variable name (i knew that..).
Fixes compiler warning. svn path=/trunk/; revision=47726
Diffstat (limited to 'print.c')
-rw-r--r--print.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/print.c b/print.c
index e032bcc72a..8b101f691f 100644
--- a/print.c
+++ b/print.c
@@ -1551,23 +1551,23 @@ void write_fields_preamble(output_fields_t* fields, FILE *fh)
static void format_field_values(output_fields_t* fields, gpointer field_index, const gchar* value)
{
- guint index;
+ guint idx;
GPtrArray* fv_p;
if (NULL == value || '\0' == *value)
return;
/* Unwrap change made to disambiguiate zero / null */
- index = GPOINTER_TO_UINT(field_index) - 1;
+ idx = GPOINTER_TO_UINT(field_index) - 1;
- if (fields->field_values[index] == NULL) {
- fields->field_values[index] = g_ptr_array_new();
+ if (fields->field_values[idx] == NULL) {
+ fields->field_values[idx] = g_ptr_array_new();
}
/* Essentially: fieldvalues[index] is an array of (ghar *) with each entry */
/* pointing to a string which is (part of) the final output string. */
- fv_p = fields->field_values[index];
+ fv_p = fields->field_values[idx];
switch (fields->occurrence) {
case 'f':
@@ -1551,23 +1551,23 @@ void write_fields_preamble(output_fields_t* fields, FILE *fh)
}
- /* Essentially: fieldvalues[index] is an array of (ghar *) with each entry */
+ /* Essentially: fieldvalues[idx] is an array of (ghar *) with each entry */
/* pointing to a string which is (part of) the final output string. */